searchNodes=[{"doc":"LibEcto is a simple wrapper for ecto , make it much easier for daily use. Why LibEcto Ecto is a great library, but it's a little bit verbose for daily use. For example, imaging you have a schema like this: defmodule Sample.Schema do use Ecto.Schema @primary_key {:id, EctoKsuid, autogenerate: true} schema &quot;test&quot; do field :name, :string field :value, :string timestamps() end def changeset(m, params) do m |&gt; cast(params, [:name, :value]) end end For most common use case, you need to write a lot of boilerplate code to do simple CRUD operation: defmodule Sample.DB do alias Sample.Schema alias Sample.Repo import Ecto.Changeset def insert_one(params) do Schema.changeset(%Schema{}, params) |&gt; Repo.insert() end def update_one(m, params) do m |&gt; change(params) |&gt; Repo.update() end def delete_one(m) do Repo.delete(m) end def get_by_id(id) do Repo.get(Schema, id, select: [:id, :name, :value]) end def get_by_id_array(id_array) do Repo.all(from m in Schema, where: m.id in ^id_array, select: [:id, :name, :value]) end def get_by_name(name) do Repo.get_by(Schema, name: name, select: [:id, :name, :value]) end #... more boilerplate code # - get by name array # - get by page # - get by prefix end But!!!!!! With LibEcto, you can code like this: defmodule Sample.DB do use LibEcto repo: Sample.Repo, schema: Sample.Schema, columns: [ :id, :name, :value ], filters: [ :id, :name ] def filter(:id, dynamic, %{&quot;id&quot; =&gt; value}) when is_bitstring(value), do: {:ok, dynamic([m], ^dynamic and m.id == ^value)} def filter(:id, dynamic, %{&quot;id&quot; =&gt; value}) when is_list(value), do: {:ok, dynamic([m], ^dynamic and m.id in ^value)} def filter(:name, dynamic, %{&quot;name&quot; =&gt; value}) when is_bitstring(value), do: {:ok, dynamic([m], ^dynamic and m.name == ^value)} def filter(:name, dynamic, %{&quot;name&quot; =&gt; {&quot;like&quot;, value}}) when is_bitstring(value), do: {:ok, dynamic([m], ^dynamic and like(m.name, value))} def filter(:name, dynamic, %{&quot;name&quot; =&gt; value}) when is_list(value), do: {:ok, dynamic([m], ^dynamic and m.name in ^value)} def filter(_, dynamic, _), do: {:ok, dynamic} # you can use ecto's ability to build complicate query or update or transaction if GenericDB can't satisfy your need def other_complicated_query_or_update() do # do something end end LibEcto will generate all the boilerplate code for you, and you can focus on your business logic: iex&gt; Sample.DB.create_one(%{name: &quot;test&quot;, value: &quot;testv&quot;}) {:ok, %Simple.Schema{id: &quot;2JIebKci1ZgKenvhllJa3PMbydB&quot;, name: &quot;test&quot;, value: &quot;testv&quot;}} iex&gt; Sample.DB.get_one(%{name: &quot;test&quot;}) {:ok, %Simple.Schema{id: &quot;2JIebKci1ZgKenvhllJa3PMbydB&quot;, name: &quot;test&quot;, value: &quot;testv&quot;}} iex&gt; Sample.DB.get_one(%{name: &quot;not-exists&quot;}) {:ok, nil} iex&gt; Sample.DB.get_one!(%{name: &quot;not-exists&quot;}) {:error, 404} iex&gt; {:ok, m} = Sample.DB.get_one(%{name: &quot;test&quot;}) iex&gt; Sample.DB.update_one(m, name: &quot;test2&quot;) {:ok, %Simple.Schema{id: &quot;2JIebKci1ZgKenvhllJa3PMbydB&quot;, name: &quot;test2&quot;, value: &quot;testv&quot;}} Installation The package can be installed by adding lib_ecto to your list of dependencies in mix.exs : def deps do [ { :lib_ecto , &quot;~&gt; 0.1.0&quot; } ] end","ref":"LibEcto.html","title":"LibEcto","type":"module"},{"doc":"base64 encode/decode implementation","ref":"LibEcto.Base62.html","title":"LibEcto.Base62","type":"module"},{"doc":"","ref":"LibEcto.Base62.html#bin_to_integer/1","title":"LibEcto.Base62.bin_to_integer/1","type":"function"},{"doc":"","ref":"LibEcto.Base62.html#decode!/1","title":"LibEcto.Base62.decode!/1","type":"function"},{"doc":"","ref":"LibEcto.Base62.html#encode/1","title":"LibEcto.Base62.encode/1","type":"function"},{"doc":"ksuid is a zero dependency Elixir library for generating and parsing KSUIDs. Read more about ksuid here ksuid stands for K-Sortable Unique Identifier. It's a way to generate globally unique IDs which are partially chronologically sortable. How To iex&gt; LibEcto.Ksuid . generate ( ) &quot;0p9kxW1vWavpdq7VSgbv8piY0nr&quot; iex&gt; LibEcto.Ksuid . parse ( &quot;0p9kxW1vWavpdq7VSgbv8piY0nr&quot; ) { :ok , % DateTime { calendar : Calendar.ISO , day : 9 , hour : 14 , microsecond : { 0 , 0 } , minute : 52 , month : 6 , second : 34 , std_offset : 0 , time_zone : &quot;Etc/UTC&quot; , utc_offset : 0 , year : 2017 , zone_abbr : &quot;UTC&quot; } , &lt;&lt; 166 , 90 , 80 , 117 , 89 , 88 , 196 , 168 , 113 , 163 , 157 , 217 , 224 , 51 , 151 , 227 &gt;&gt; } Example Ecto Usage Ecto Type defmodule LibEcto.KsuidType do @moduledoc &quot;&quot;&quot; types for ksuid uses string/varchar as storage type. &quot;&quot;&quot; @behaviour Ecto.Type alias LibEcto.Ksuid def type , do : :string def cast ( ksuid ) when is_binary ( ksuid ) , do : { :ok , ksuid } def cast ( _ ) , do : :error @doc &quot;&quot;&quot; Same as `cast/1` but raises `Ecto.CastError` on invalid arguments. &quot;&quot;&quot; def cast! ( value ) do case cast ( value ) do { :ok , ksuid } -&gt; ksuid :error -&gt; raise Ecto.CastError , type : __MODULE__ , value : value end end def load ( ksuid ) , do : { :ok , ksuid } def dump ( binary ) when is_binary ( binary ) , do : { :ok , binary } def dump ( _ ) , do : :error # Callback invoked by autogenerate fields - this is all that really matters # just passing around the binary otherwise. @doc false def autogenerate , do : Ksuid . generate ( ) end Usage in a Schema :inserted_at is a virtual field that can be derived/loaded from the autogenerated :id defmodule TestSchema do use Ecto.Schema @primary_key { :id , KsuidType , autogenerate : true } schema &quot;test&quot; do field :name , :string field :inserted_at , :utc_datetime , virtual : true end def inserted_at ( % TestSchema { id : ksuid } = row ) do { :ok , time_stamp , _ } = LibEcto.Ksuid . parse ( ksuid ) % TestSchema { row | inserted_at : time_stamp } end end Migration Create :id as :bytea , and primary key - similary to usage with :binary_id def change do create table ( :test , primary_key : false ) do add :id , :string , primary_key : true , size : 27 add :name , :text end end","ref":"LibEcto.Ksuid.html","title":"LibEcto.Ksuid","type":"module"},{"doc":"This method returns a 20 byte Ksuid which has 4 bytes as timestamp and 16 bytes of crypto string bytes. Examples iex&gt; Ksuid . generate ( ) &quot;0KZi94b2fnVzpGi60FoZgXIvUtYy&quot;","ref":"LibEcto.Ksuid.html#generate/0","title":"LibEcto.Ksuid.generate/0","type":"function"},{"doc":"","ref":"LibEcto.Ksuid.html#parse/1","title":"LibEcto.Ksuid.parse/1","type":"function"},{"doc":"types for ksuid uses string/varchar as storage type. Example defmodule TestSchema do use Ecto.Schema alias LibEcto.KsuidType @primary_key {:id, KsuidType, autogenerate: true} schema &quot;test&quot; do field :name, :string field :inserted_at, :utc_datetime, virtual: true end def inserted_at(%TestSchema{id: ksuid} = row) do {:ok, time_stamp, _} = LibEcto.Ksuid.parse(ksuid) %TestSchema{row | inserted_at: time_stamp} end end","ref":"LibEcto.KsuidType.html","title":"LibEcto.KsuidType","type":"module"},{"doc":"Callback implementation for Ecto.Type.cast/1 .","ref":"LibEcto.KsuidType.html#cast/1","title":"LibEcto.KsuidType.cast/1","type":"function"},{"doc":"Same as cast/1 but raises Ecto.CastError on invalid arguments.","ref":"LibEcto.KsuidType.html#cast!/1","title":"LibEcto.KsuidType.cast!/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.dump/1 .","ref":"LibEcto.KsuidType.html#dump/1","title":"LibEcto.KsuidType.dump/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.embed_as/1 .","ref":"LibEcto.KsuidType.html#embed_as/1","title":"LibEcto.KsuidType.embed_as/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.equal?/2 .","ref":"LibEcto.KsuidType.html#equal?/2","title":"LibEcto.KsuidType.equal?/2","type":"function"},{"doc":"Callback implementation for Ecto.Type.load/1 .","ref":"LibEcto.KsuidType.html#load/1","title":"LibEcto.KsuidType.load/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.type/0 .","ref":"LibEcto.KsuidType.html#type/0","title":"LibEcto.KsuidType.type/0","type":"function"}]